==> jc-1.4.0.tar.gz: soot/javaToJimple/AnonClassInitMethodSource.h <==
// public class soot.javaToJimple.AnonClassInitMethodSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 254762550456ada1 soot_javaToJimple_AnonClassInitMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_AnonClassInitMethodSource_H_
#define _JC_soot_javaToJimple_AnonClassInitMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_refs	_jc_soot_javaToJimple_AnonClassInitMethodSource$sub_refs;
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_nonrefs	_jc_soot_javaToJimple_AnonClassInitMethodSource$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$refs	_jc_soot_javaToJimple_AnonClassInitMethodSource$refs;
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$nonrefs	_jc_soot_javaToJimple_AnonClassInitMethodSource$nonrefs;
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object	_jc_soot_javaToJimple_AnonClassInitMethodSource$object;

typedef const struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vmethods	_jc_soot_javaToJimple_AnonClassInitMethodSource$vmethods;
typedef const struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vtable	_jc_soot_javaToJimple_AnonClassInitMethodSource$vtable;
typedef const struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vtype	_jc_soot_javaToJimple_AnonClassInitMethodSource$vtype;

// Constructors
extern void _jc_soot_javaToJimple_AnonClassInitMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *);

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_javaToJimple_AnonClassInitMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
extern struct _jc_soot_Type$object *_jc_soot_javaToJimple_AnonClassInitMethodSource$method$outerClassType$abf35eb24a88b1e1(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *);
extern void _jc_soot_javaToJimple_AnonClassInitMethodSource$method$outerClassType$fc36bcc09e575f38(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_soot_Type$object *);
extern void _jc_soot_javaToJimple_AnonClassInitMethodSource$method$setFieldList$c8be9a993bdb0ffe(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_java_util_ArrayList$object *);
extern void _jc_soot_javaToJimple_AnonClassInitMethodSource$method$setFinalLocals$aecfd3b8cf8a54ca(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_java_util_ArrayList$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$getBody$01a871f1d690f082;
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$outerClassType$abf35eb24a88b1e1;
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$outerClassType$fc36bcc09e575f38;
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$setFieldList$c8be9a993bdb0ffe;
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$setFinalLocals$aecfd3b8cf8a54ca;

// Virtual methods structure
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
	struct _jc_soot_Type$object	*(*outerClassType$abf35eb24a88b1e1)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *);
	void	(*outerClassType$fc36bcc09e575f38)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_soot_Type$object *);
	void	(*setFieldList$c8be9a993bdb0ffe)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_java_util_ArrayList$object *);
	void	(*setFinalLocals$aecfd3b8cf8a54ca)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_java_util_ArrayList$object *);
};

// Vtable
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_AnonClassInitMethodSource$vmethods	soot_javaToJimple_AnonClassInitMethodSource;
};

// Vtype
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_AnonClassInitMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_refs {
	struct _jc_java_util_ArrayList$object	*finalLocals;
	struct _jc_java_util_ArrayList$object	*fields;
	struct _jc_soot_Type$object	*outerClassType;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$refs {
    _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_refs	soot_javaToJimple_AnonClassInitMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_nonrefs	soot_javaToJimple_AnonClassInitMethodSource;
};

// Object instance structure
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object {
	_jc_soot_javaToJimple_AnonClassInitMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_AnonClassInitMethodSource$vtype	*vtype;
	_jc_soot_javaToJimple_AnonClassInitMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_AnonClassInitMethodSource$vtype _jc_soot_javaToJimple_AnonClassInitMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_AnonClassInitMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_AnonClassInitMethodSource$class_object;

#endif	/* _JC_soot_javaToJimple_AnonClassInitMethodSource_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/AnonClassInitMethodSource.h <==
// public class soot.javaToJimple.AnonClassInitMethodSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 254762550456ada1 soot_javaToJimple_AnonClassInitMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_AnonClassInitMethodSource_H_
#define _JC_soot_javaToJimple_AnonClassInitMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_refs	_jc_soot_javaToJimple_AnonClassInitMethodSource$sub_refs;
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_nonrefs	_jc_soot_javaToJimple_AnonClassInitMethodSource$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$refs	_jc_soot_javaToJimple_AnonClassInitMethodSource$refs;
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$nonrefs	_jc_soot_javaToJimple_AnonClassInitMethodSource$nonrefs;
typedef struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object	_jc_soot_javaToJimple_AnonClassInitMethodSource$object;

typedef const struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vmethods	_jc_soot_javaToJimple_AnonClassInitMethodSource$vmethods;
typedef const struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vtable	_jc_soot_javaToJimple_AnonClassInitMethodSource$vtable;
typedef const struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vtype	_jc_soot_javaToJimple_AnonClassInitMethodSource$vtype;

// Constructors
extern void _jc_soot_javaToJimple_AnonClassInitMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_javaToJimple_AnonClassInitMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_javaToJimple_AnonClassInitMethodSource$method$outerClassType$abf35eb24a88b1e1(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_AnonClassInitMethodSource$method$outerClassType$fc36bcc09e575f38(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_AnonClassInitMethodSource$method$setFieldList$c8be9a993bdb0ffe(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_java_util_ArrayList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_javaToJimple_AnonClassInitMethodSource$method$setFinalLocals$aecfd3b8cf8a54ca(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_java_util_ArrayList$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$getBody$01a871f1d690f082;
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$outerClassType$abf35eb24a88b1e1;
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$outerClassType$fc36bcc09e575f38;
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$setFieldList$c8be9a993bdb0ffe;
extern _jc_method _jc_soot_javaToJimple_AnonClassInitMethodSource$method_info$setFinalLocals$aecfd3b8cf8a54ca;

// Virtual methods structure
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*outerClassType$abf35eb24a88b1e1)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *) _JC_JCNI_ATTR;
	void	(*outerClassType$fc36bcc09e575f38)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	void	(*setFieldList$c8be9a993bdb0ffe)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_java_util_ArrayList$object *) _JC_JCNI_ATTR;
	void	(*setFinalLocals$aecfd3b8cf8a54ca)(_jc_env *, struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object *, struct _jc_java_util_ArrayList$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_AnonClassInitMethodSource$vmethods	soot_javaToJimple_AnonClassInitMethodSource;
};

// Vtype
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_AnonClassInitMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_refs {
	struct _jc_java_util_ArrayList$object	*finalLocals;
	struct _jc_java_util_ArrayList$object	*fields;
	struct _jc_soot_Type$object	*outerClassType;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$refs {
    _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_refs	soot_javaToJimple_AnonClassInitMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_AnonClassInitMethodSource$sub_nonrefs	soot_javaToJimple_AnonClassInitMethodSource;
};

// Object instance structure
struct _jc_soot_javaToJimple_AnonClassInitMethodSource$object {
	_jc_soot_javaToJimple_AnonClassInitMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_AnonClassInitMethodSource$vtype	*vtype;
	_jc_soot_javaToJimple_AnonClassInitMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_AnonClassInitMethodSource$vtype _jc_soot_javaToJimple_AnonClassInitMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_AnonClassInitMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_AnonClassInitMethodSource$class_object;

#endif	/* _JC_soot_javaToJimple_AnonClassInitMethodSource_H_ */
